import { defineStore } from 'pinia';
import {
  login as userLogin,
  LoginData,
  logout as userLoginOut,
} from '@/api/user';
import { setToken, clearToken, setNickName, clearNickName } from '@/utils/auth';
import { removeRouteListener } from '@/utils/route-listener';
import { UserState } from './types';
import { ROLES_KEY } from '@/utils/cache/key';
import { createLocalStorage } from '@/utils/cache';
import useAppStore from '../app';

const useUserStore = defineStore('user', {
  state: (): UserState => ({
    name: undefined,
    avatar: undefined,
    job: undefined,
    organization: undefined,
    location: undefined,
    email: undefined,
    nickname: undefined,
    introduction: undefined,
    personalWebsite: undefined,
    jobName: undefined,
    organizationName: undefined,
    locationName: undefined,
    phone: undefined,
    registrationDate: undefined,
    accountId: undefined,
    certification: undefined,
    role: '',
  }),

  getters: {
    userInfo(state: UserState): UserState {
      return { ...state };
    },
    getNickName(): string {
      return this.nickname || localStorage.getItem('nickname') || '';
    },
    getRole(): string {
      return this.role || createLocalStorage().get(ROLES_KEY) || '';
    },
  },

  actions: {
    setInfo(partial: Partial<UserState>) {
      this.$patch(partial);
    },

    // Reset user's information
    resetInfo() {
      this.$reset();
    },

    // Login
    async login(loginForm: LoginData) {
      try {
        const res = await userLogin(loginForm);
        console.log(res);
        setToken(res.data.token);
        setNickName(res.data.nickname);
        this.setInfo({ nickname: res.data.nickname });
        createLocalStorage().set(ROLES_KEY, res.data.role);
        this.role = res.data.role;
      } catch (err) {
        clearToken();
        throw err;
      }
    },
    logoutCallBack() {
      const appStore = useAppStore();
      this.resetInfo();
      clearToken();
      clearNickName();
      removeRouteListener();
      appStore.clearServerMenu();
    },
    // Logout
    async logout() {
      await userLoginOut();
      this.logoutCallBack();
    },
  },
});

export default useUserStore;
