import { createStorage as create, CreateStorageParams } from './storage';

//storage默认缓存有效期 7天
const DEFAULT_CACHE_TIME = 60 * 60 * 24 * 30;
//缓存前缀
const DEFAULT_CACHE_NAME = 'ZW__MANAGE__';
export type Options = Partial<CreateStorageParams>;

const createOptions = (storage: Storage, options: Options = {}): Options => {
  return {
    storage,
    prefixKey: DEFAULT_CACHE_NAME,
    ...options,
  };
};

export const WebStorage = create(createOptions(sessionStorage));

export const createStorage = (
  storage: Storage = sessionStorage,
  options: Options = {}
) => {
  return create(createOptions(storage, options));
};

export const createSessionStorage = (options: Options = {}) => {
  return createStorage(sessionStorage, {
    ...options,
    timeout: DEFAULT_CACHE_TIME,
  });
};

export const createLocalStorage = (options: Options = {}) => {
  return createStorage(localStorage, {
    ...options,
    timeout: DEFAULT_CACHE_TIME,
  });
};

export default WebStorage;
